@@ -11,7 +11,7 @@
 # Author   : Kenneth J. Pronovici <pronovic@ieee.org>
 # Language : Python (>= 2.5)
 # Project  : Cedar Backup, release 2
-# Revision : $Id: release.py 1026 2011-10-12 14:22:54Z pronovic $
+# Revision : $Id: release.py 1029 2013-03-21 14:38:17Z pronovic $
 # Purpose  : Provides location to maintain release information.
 #
 # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # #
@@ -33,8 +33,8 @@ Provides location to maintain version information.
 
 AUTHOR      = "Kenneth J. Pronovici"
 EMAIL       = "pronovic@ieee.org"
-COPYRIGHT   = "2004-2011"
-VERSION     = "2.21.0"
-DATE        = "12 Oct 2011"
+COPYRIGHT   = "2004-2011,2013"
+VERSION     = "2.21.1"
+DATE        = "21 Mar 2013"
 URL         = "http://cedar-backup.sourceforge.net/"
 
